Actions, Resources, and Condition Keys for Amazon Lex - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Lex.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

The AWS Documentation website is getting a new look!
Try it now and let us know what you think. Switch to the new look >>
You can return to the original look by selecting English in the language selector above.

# Actions, Resources, and Condition Keys for Amazon Lex

Amazon Lex (service prefix: `lex`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Lex
- Resources Defined by Amazon Lex
- Condition Keys for Amazon Lex

## Actions Defined by Amazon Lex

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
CreateBotVersion | Creates a new version based on the $LATEST version of the specified bot. | Write | bot* |  |
CreateIntentVersion | Creates a new version based on the $LATEST version of the specified intent. | Write | intent* |  |
CreateSlotTypeVersion | Creates a new version based on the $LATEST version of the specified slot type. | Write | slottype* |  |
DeleteBot | Deletes all versions of a bot. | Write | bot* |  |
DeleteBotAlias | Deletes an alias for a specific bot. | Write | bot* |  |
DeleteBotChannelAssociation | Deletes the association between a Amazon Lex bot alias and a messaging platform. | Write | channel* |  |
DeleteBotVersion | Deletes a specific version of a bot. | Write | bot* |  |
DeleteIntent | Deletes all versions of an intent. | Write | intent* |  |
DeleteIntentVersion | Deletes a specific version of an intent. | Write | intent* |  |
DeleteSlotType | Deletes all versions of a slot type. | Write | slottype* |  |
DeleteSlotTypeVersion | Deletes a specific version of a slot type. | Write | slottype* |  |
DeleteUtterances | Deletes the information Amazon Lex maintains for utterances on a specific bot and userId. | Write | bot* |  |
GetBot | Returns information for a specific bot. In addition to the bot name, the bot version or alias is required. | Read | bot* |  |
GetBotAlias | Returns information about a Amazon Lex bot alias. | Read | bot* |  |
GetBotAliases | Returns a list of aliases for a given Amazon Lex bot. | List | bot* |  |
GetBotChannelAssociation | Returns information about the association between a Amazon Lex bot and a messaging platform. | Read | channel* |  |
GetBotChannelAssociations | Returns a list of all of the channels associated with a single bot. | List | channel* |  |
GetBotVersions | Returns information for all versions of a specific bot. | List | bot* |  |
GetBots | Returns information for the $LATEST version of all bots, subject to filters provided by the client. | List |  |  |
GetBuiltinIntent | Returns information about a built-in intent. | Read |  |  |
GetBuiltinIntents | Gets a list of built-in intents that meet the specified criteria. | Read |  |  |
GetBuiltinSlotTypes | Gets a list of built-in slot types that meet the specified criteria. | Read |  |  |
GetIntent | Returns information for a specific intent. In addition to the intent name, you must also specify the intent version. | Read | intent* |  |
GetIntentVersions | Returns information for all versions of a specific intent. | List | intent* |  |
GetIntents | Returns information for the $LATEST version of all intents, subject to filters provided by the client. | List |  |  |
GetSlotType | Returns information about a specific version of a slot type. In addition to specifying the slot type name, you must also specify the slot type version. | Read | slottype* |  |
GetSlotTypeVersions | Returns information for all versions of a specific slot type. | List | slottype* |  |
GetSlotTypes | Returns information for the $LATEST version of all slot types, subject to filters provided by the client. | List |  |  |
GetUtterancesView | Returns a view of aggregate utterance data for versions of a bot for a recent time period. | List | bot* |  |
PostContent | Sends user input (text or speech) to Amazon Lex. | Write | bot* |  |
PostText | Sends user input (text-only) to Amazon Lex. | Write | bot* |  |
PutBot | Creates or updates the $LATEST version of a Amazon Lex conversational bot. | Write | bot* |  |
PutBotAlias | Creates or updates an alias for the specific bot. | Write | bot* |  |
PutIntent | Creates or updates the $LATEST version of an intent. | Write | intent* |  |
PutSlotType | Creates or updates the $LATEST version of a slot type. | Write | slottype* |  |

## Resources Defined by Amazon Lex

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
bot | `arn:${Partition}:lex:${Region}:${Account}:bot:${BotName}:${BotVersionOrAlias}` |
channel | `arn:${Partition}:lex:${Region}:${Account}:bot-channel:${BotName}:${BotAlias}:${ChannelName}` |
intent | `arn:${Partition}:lex:${Region}:${Account}:intent:${IntentName}:${IntentVersion}` |
slottype | `arn:${Partition}:lex:${Region}:${Account}:slottype:${SlotName}:${SlotVersion}` |

## Condition Keys for Amazon Lex

Amazon Lex defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
lex:associatedIntents | Enables you to control access based on the intents included in the request. | String
lex:associatedSlotTypes | Enables you to control access based on the slot types included in the request. | String
lex:channelType | Enables you to control access based on the channel type included in the request. | String

On this page:

- Actions Defined by Amazon Lex
- Resources Defined by Amazon Lex
- Condition Keys for Amazon Lex

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more